@@ -28,13 +28,13 @@ class Client(metaclass=abc.ABCMeta):
         response = await fn(*args, **kwargs)
         if 'X-Canonical-Exception' in response.headers:
             dto = await self.fromjson(response)
-            if retry or dto.code != 'CREDENTIAL_EXPIRED':
+            if retry or dto.code not in ('CREDENTIAL_EXPIRED', 'TRUST_ISSUES'):
                 exception = CanonicalException(**dto)
                 exception.http_status_code = response.status
                 raise exception
 
-            # If the code is CREDENTIAL_EXPIRED, then refresh the
-            # access token and retry the request.
+            # If the code is CREDENTIAL_EXPIRED or TRUST_ISSUES, then refresh
+            # the access token and retry the request.
             kwargs['retry'] = True
             await self.refresh_credentials()
             return await self.request(fn, *args, **kwargs)
